
#### Applied Example BSEM chapter

library(blavaan)
#future::plan("multiprocess")

dat <- read.table('ECLS_Science.dat', na.string='.')
head(dat)

# Give the variable names
names(dat)<-c('id','s_g3','r_g3','m_g3',
                's_g5','r_g5','m_g5', 
                's_g8','r_g8','m_g8', 
                'st_g3','rt_g3','mt_g3', 
                'st_g5','rt_g5','mt_g5', 
                'st_g8','rt_g8','mt_g8')

dat <- na.omit(dat[,c("s_g3","r_g3","m_g3",
                      "s_g5","r_g5","m_g5",
                      "s_g8","r_g8","m_g8")])

dim(dat)

## check the data and descriptives
head(dat)
summary(dat)
psych::describe(dat)

###### estimate the NULL model (to be able to calculate CFI)
null_mod <- '
#### item intercepts
s_g3 ~prior("normal(50, 40)")*1
r_g3 ~prior("normal(127, 40)")*1 
m_g3 ~prior("normal(100, 40)")*1
s_g5 ~prior("normal(65, 40)")*1
r_g5 ~prior("normal(151, 40)")*1
m_g5 ~prior("normal(125, 40)")*1
s_g8 ~prior("normal(85, 40)")*1
r_g8 ~prior("normal(172, 40)")*1
m_g8 ~prior("normal(142, 40)")*1

#### item variances
s_g3 ~~ v1*s_g3
r_g3 ~~ v2*r_g3
m_g3 ~~ v3*m_g3
s_g5 ~~ v1*s_g5
r_g5 ~~ v2*r_g5
m_g5 ~~ v3*m_g5
s_g8 ~~ v1*s_g8
r_g8 ~~ v2*r_g8
m_g8 ~~ v3*m_g8
'

fit0 <- bcfa(null_mod, 
             data = dat,
             n.chains = 3, 
             burnin = 3000, 
             sample = 1000,
             target="stan",
             bcontrol = list(cores=3))
summary(fit0, standardized=T)


#############
#### Configural Invariance
#############
conf_mod <- '
#### factor loadings
ft3 =~ s_g3 + r_g3 + m_g3
ft5 =~ s_g5 + r_g5 + m_g5
ft8 =~ s_g8 + r_g8 + m_g8

#### residual covariances
s_g3 ~~ s_g5 + s_g8
s_g5 ~~ s_g8
r_g3 ~~ r_g5 + r_g8
r_g5 ~~ r_g8
m_g3 ~~ m_g5 + m_g8
m_g5 ~~ m_g8

#### Factor means
ft3 ~0*1
ft5 ~0*1
ft8 ~0*1

#### factor variances
ft3 ~~ 1*ft3
ft5 ~~ 1*ft5
ft8 ~~ 1*ft8

#### item intercepts
s_g3 ~prior("normal(50, 40)")*1
r_g3 ~prior("normal(127, 40)")*1 
m_g3 ~prior("normal(100, 40)")*1
s_g5 ~prior("normal(65, 40)")*1
r_g5 ~prior("normal(151, 40)")*1
m_g5 ~prior("normal(125, 40)")*1
s_g8 ~prior("normal(85, 40)")*1
r_g8 ~prior("normal(172, 40)")*1
m_g8 ~prior("normal(142, 40)")*1
'
fml <- cfa(conf_mod, 
           std.lv=T,
           data = dat)
summary(fml, standardized=T)


fit_config <- bcfa(conf_mod, 
                   std.lv=T,
             data = dat,
             n.chains = 3, 
             burnin = 3000, 
             sample = 1000,
             target="stan",
             dp=dpriors(lambda="normal(15, 10)"),
             bcontrol = list(cores=3))

summary(fit_config, 
        standardize=T, 
        rsquare=T,
        neff=T)

### fitmeasures output 
fm_conf <- fitMeasures(fit_config)
fm_conf

### approximate fit indices
apx_conf <- blavFitIndices(fit_config, baseline.model = fit0)
apx_conf
summary(apx_conf, "mean")



#############
#### Weak Invariance
#############
weak_mod <- '
#### factor loadings
ft3 =~ l1*s_g3 + l2*r_g3 + l3*m_g3
ft5 =~ l1*s_g5 + l2*r_g5 + l3*m_g5
ft8 =~ l1*s_g8 + l2*r_g8 + l3*m_g8

#### residual covariances
s_g3 ~~ s_g5 + s_g8
s_g5 ~~ s_g8
r_g3 ~~ r_g5 + r_g8
r_g5 ~~ r_g8
m_g3 ~~ m_g5 + m_g8
m_g5 ~~ m_g8

#### Factor means
ft3 ~0*1
ft5 ~0*1
ft8 ~0*1

#### factor variances
ft3 ~~ 1*ft3
ft5 ~~ NA*ft5
ft8 ~~ NA*ft8

#### item intercepts
s_g3 ~prior("normal(50, 40)")*1
r_g3 ~prior("normal(127, 40)")*1 
m_g3 ~prior("normal(100, 40)")*1
s_g5 ~prior("normal(65, 40)")*1
r_g5 ~prior("normal(151, 40)")*1
m_g5 ~prior("normal(125, 40)")*1
s_g8 ~prior("normal(85, 40)")*1
r_g8 ~prior("normal(172, 40)")*1
m_g8 ~prior("normal(142, 40)")*1
'

fit_weak <- bcfa(weak_mod, 
                 std.lv=T,
                   data = dat,
                   n.chains = 3, 
                   burnin = 3000, 
                   sample = 1000,
                   target="stan",
                 dp=dpriors(lambda="normal(15, 10)"),
                   bcontrol = list(cores=3))

summary(fit_weak, 
        standardize=T, 
        rsquare=T,
        neff=T)

### fitmeasures output 
fm_weak <- fitMeasures(fit_weak)
fm_weak

### approximate fit indices
apx_weak <- blavFitIndices(fit_weak, baseline.model = fit0)
apx_weak
summary(apx_weak,"mean")

### comparison: Configural vs Weak
comp_CW <- blavCompare(fit_config, fit_weak)
comp_CW
comp_CW$diff_loo
comp_CW$diff_loo[1]/comp_CW$diff_loo[2]


#############
#### APPROXIMATE Weak Invariance
#############

fit_APweak <- bcfa(weak_mod, 
                 std.lv=T,
                 data = dat,
                 wiggle = c("l1","l2","l3"),
                 wiggle.sd = 0.05,
                 n.chains = 3, 
                 burnin = 3000, 
                 sample = 1000,
                 target="stan",
                 dp=dpriors(lambda="normal(15, 10)"),
                 bcontrol = list(cores=3))

summary(fit_APweak, 
        standardize=T, 
        rsquare=T,
        neff=F)

### fitmeasures output 
fm_APweak <- fitMeasures(fit_APweak)
fm_APweak

### approximate fit indices
apx_APweak <- blavFitIndices(fit_APweak, baseline.model = fit0)
apx_APweak
summary(apx_APweak,"mean")

### comparison: Configural vs APPROXIMATE Weak
comp_CAPW <- blavCompare(fit_config, fit_APweak)
comp_CAPW$diff_loo

### comparison: Weak vs APPROXIMATE Weak
comp_WAPW <- blavCompare(fit_weak, fit_APweak)
comp_WAPW


### posterior draws
posts_APW <- data.frame(as.matrix(blavInspect(fit_APweak, "mcmc")))
head(posts_APW)

## plot approximate invariance factor loadings
plot(density(posts_APW$ly_sign.1.), type="l")
lines(density(posts_APW$ly_sign.4.), col="red")
lines(density(posts_APW$ly_sign.7.), col="blue")

tiff("Plot3.tiff", width = 9.5, height = 5.5, units = 'in', 
     res = 300)
par(mfrow=c(1,3))
plot(density(posts_APW$ly_sign.1.), type="l",
     main="Factor Loadings \n Science",
     xlab = "Unstandardized estimate")
lines(density(posts_APW$ly_sign.4.), col="black", lty=2,
      xlab = "Unstandardized estimate")
lines(density(posts_APW$ly_sign.7.), col="black", lty=3,
      xlab = "Unstandardized estimate")
legend("topright", col=c("black","black","black"),
       lty=c(1,2,3), 
       legend=c("3th grade","5th grade","8th grade") )

plot(density(posts_APW$ly_sign.2.), type="l",
     main="Factor Loadings \n Reading",
     xlab = "Unstandardized estimate")
lines(density(posts_APW$ly_sign.5.), col="black", lty=2,
      xlab = "Unstandardized estimate")
lines(density(posts_APW$ly_sign.8.), col="black", lty=3,
      xlab = "Unstandardized estimate")

plot(density(posts_APW$ly_sign.3.), type="l",
     main="Factor Loadings \n Mathematics",
     xlab = "Unstandardized estimate")
lines(density(posts_APW$ly_sign.6.), col="black", lty=2,
      xlab = "Unstandardized estimate")
lines(density(posts_APW$ly_sign.9.), col="black", lty=3,
      xlab = "Unstandardized estimate")
par(mfrow=c(1,1))
dev.off()

##### 
#############
#### PARTIAL APPROXIMATE Weak Invariance
#############

weak_mod_partial <- '
#### factor loadings
ft3 =~ l1a*s_g3 + l2*r_g3 + l3*m_g3
ft5 =~ l1b*s_g5 + l2*r_g5 + l3*m_g5
ft8 =~ l1b*s_g8 + l2*r_g8 + l3*m_g8

#### residual covariances
s_g3 ~~ s_g5 + s_g8
s_g5 ~~ s_g8
r_g3 ~~ r_g5 + r_g8
r_g5 ~~ r_g8
m_g3 ~~ m_g5 + m_g8
m_g5 ~~ m_g8

#### Factor means
ft3 ~0*1
ft5 ~0*1
ft8 ~0*1

#### factor variances
ft3 ~~ 1*ft3
ft5 ~~ NA*ft5
ft8 ~~ NA*ft8

#### item intercepts
s_g3 ~1
r_g3 ~1 
m_g3 ~1
s_g5 ~1
r_g5 ~1
m_g5 ~1
s_g8 ~1
r_g8 ~1
m_g8 ~1
'


fit_PAPweak <- bcfa(weak_mod_partial, 
                   std.lv=T,
                   data = dat,
                   wiggle = c("l1b","l2","l3"),
                   wiggle.sd = 0.05,
                   n.chains = 3, 
                   burnin = 3000, 
                   sample = 1000,
                   target="stan",
                   dp=dpriors(lambda="normal(15, 10)"),
                   bcontrol = list(cores=3))

summary(fit_PAPweak, 
        standardize=T, 
        rsquare=T,
        neff=T)

### fitmeasures output 
fm_PAPweak <- fitMeasures(fit_PAPweak)

### approximate fit indices
apx_PAPweak <- blavFitIndices(fit_PAPweak, baseline.model = fit0)
apx_PAPweak
summary(apx_PAPweak)


### comparison: Configural vs PARTIAL APPROXIMATE Weak
comp_CPAPW <- blavCompare(fit_config, fit_PAPweak)
comp_CPAPW

### comparison: Weak vs PARTIAL APPROXIMATE Weak
comp_WPAPW <- blavCompare(fit_weak, fit_PAPweak)
comp_WPAPW



########
#### PARTIAL INVARIANCE
##########

fit_Pweak <- bcfa(weak_mod_partial, 
                    std.lv=T,
                    data = dat,
                    n.chains = 3, 
                    burnin = 3000, 
                    sample = 1000,
                    target="stan",
                  dp=dpriors(lambda="normal(15, 10)"),
                    bcontrol = list(cores=3))

summary(fit_Pweak, 
        standardize=T, 
        rsquare=T,
        neff=T)

### fitmeasures output 
fm_Pweak <- fitMeasures(fit_Pweak)
fm_Pweak

### approximate fit indices
apx_Pweak <- blavFitIndices(fit_Pweak, baseline.model = fit0)
apx_Pweak
summary(apx_Pweak,"mean")


### comparison: Configural vs PARTIAL Weak
comp_CPW <- blavCompare(fit_config, fit_Pweak)
comp_CPW

### comparison: Weak vs PARTIAL Weak
comp_WPW <- blavCompare(fit_weak, fit_Pweak)
comp_WPW

### comparison:  PARTIAL APPROXIMATE Weak vs PARTIAL Weak
comp_PAPWPW <- blavCompare(fit_PAPweak, fit_Pweak)
comp_PAPWPW


########
#### PARTIAL INVARIANCE 2
##########

weak_mod_partial_2 <- '
#### factor loadings
ft3 =~ l1a*s_g3 + l2*r_g3 + l3*m_g3
ft5 =~ l1b*s_g5 + l2*r_g5 + l3*m_g5
ft8 =~ l1b*s_g8 + l2*r_g8 + l3*m_g8

#### residual covariances
s_g3 ~~ s_g5 + s_g8
s_g5 ~~ s_g8
r_g3 ~~ r_g5 + r_g8
r_g5 ~~ r_g8
m_g3 ~~ m_g5 + m_g8
m_g5 ~~ m_g8

#### Factor means
ft3 ~0*1
ft5 ~0*1
ft8 ~0*1

#### factor variances
ft3 ~~ 1*ft3
ft5 ~~ NA*ft5
ft8 ~~ NA*ft8

#### item intercepts
s_g3 ~1
r_g3 ~1 
m_g3 ~1
s_g5 ~1
r_g5 ~1
m_g5 ~1
s_g8 ~1
r_g8 ~1
m_g8 ~1
'


fit_P2weak <- bcfa(weak_mod_partial_2, 
                  std.lv=T,
                  data = dat,
                  wiggle = c("l1b"),
                  wiggle.sd = 0.35,
                  n.chains = 3, 
                  burnin = 3000, 
                  sample = 1000,
                  target="stan",
                  dp=dpriors(lambda="normal(15, 10)"),
                  bcontrol = list(cores=3))

summary(fit_P2weak, 
        standardize=T, 
        rsquare=T,
        neff=T)

### fitmeasures output 
fm_P2weak <- fitMeasures(fit_P2weak)

### approximate fit indices
apx_P2weak <- blavFitIndices(fit_P2weak, baseline.model = fit0)
apx_P2weak
summary(apx_P2weak)


### comparison: Configural vs PARTIAL2 Weak
comp_CP2W <- blavCompare(fit_config, fit_P2weak)
comp_CP2W


### comparison: Weak vs PARTIAL2 Weak
comp_WP2W <- blavCompare(fit_weak, fit_P2weak)
comp_WP2W



### chosen model : fit_Pweak



###########
###########
######STRONG INVARIANCE
###########
###########


strong_mod <- '
#### factor loadings
ft3 =~ l1a*s_g3 + l2*r_g3 + l3*m_g3
ft5 =~ l1b*s_g5 + l2*r_g5 + l3*m_g5
ft8 =~ l1b*s_g8 + l2*r_g8 + l3*m_g8

#### residual covariances
s_g3 ~~ s_g5 + s_g8
s_g5 ~~ s_g8
r_g3 ~~ r_g5 + r_g8
r_g5 ~~ r_g8
m_g3 ~~ m_g5 + m_g8
m_g5 ~~ m_g8

#### Factor means
ft3 ~0*1
ft5 ~NA*1
ft8 ~NA*1

#### factor variances
ft3 ~~ 1*ft3
ft5 ~~ NA*ft5
ft8 ~~ NA*ft8

#### item intercepts
s_g3 ~i1*1
r_g3 ~i2*1 
m_g3 ~i3*1
s_g5 ~i1*1
r_g5 ~i2*1
m_g5 ~i3*1
s_g8 ~i1*1
r_g8 ~i2*1
m_g8 ~i3*1
'


fit_strong <- bcfa(strong_mod, 
                    std.lv=T,
                    data = dat,
                    n.chains = 3, 
                    burnin = 3000, 
                    sample = 1000,
                    target="stan",
                   dp=dpriors(lambda="normal(15, 10)"),
                    bcontrol = list(cores=3))

summary(fit_strong, 
        standardize=T, 
        rsquare=T,
        neff=T)

### fitmeasures output 
fm_strong <- fitMeasures(fit_strong)
fm_strong

### approximate fit indices
apx_strong <- blavFitIndices(fit_strong, baseline.model = fit0)
apx_strong
summary(apx_strong,"mean")


### comparison: PARTIAL WEAK VS STRONG
comp_PWS <- blavCompare(fit_Pweak, fit_strong)
comp_PWS



########
##### APROXIMATE STRONG INVARIANCE
########

fit_APstrong <- bcfa(strong_mod, 
                   std.lv=T,
                   data = dat,
                   wiggle = c("i1","i2","i3"),
                   wiggle.sd = 0.05,
                   n.chains = 3, 
                   burnin = 3000, 
                   sample = 1000,
                   target="stan",
                   dp=dpriors(lambda="normal(15, 10)"),
                   bcontrol = list(cores=3))

summary(fit_APstrong, 
        standardize=T, 
        rsquare=T,
        neff=T)

### fitmeasures output 
fm_APstrong <- fitMeasures(fit_APstrong)
fm_APstrong

### approximate fit indices
apx_APstrong <- blavFitIndices(fit_APstrong, baseline.model = fit0)
apx_APstrong
summary(apx_APstrong,"mean")


### comparison: PARTIAL WEAK VS APPROXIMATE STRONG
comp_PWAPS <- blavCompare(fit_Pweak, fit_APstrong)
comp_PWAPS


### posteriors
posts_APS <- data.frame(as.matrix(blavInspect(fit_APstrong,"mcmc")))
head(posts_APS)

## plot approximate invariance parameters
tiff("Plot3.tiff", width = 9.5, height = 5.5, units = 'in', 
     res = 300)
par(mfrow=c(1,3))
plot(density(posts_APS$Nu_free.1.), type="l",
     main="Intercepts \n Science",
     xlab = "Unstandardized estimate")
lines(density(posts_APS$Nu_free.4.), col="black", lty=2)
lines(density(posts_APS$Nu_free.7.), col="black", lty=3)

plot(density(posts_APS$Nu_free.2.), type="l",
     main="Intercepts \n Reading",
     xlab = "Unstandardized estimate")
lines(density(posts_APS$Nu_free.5.), col="black", lty=2)
lines(density(posts_APS$Nu_free.8.), col="black", lty=3)
legend("topright", lty=c(1,2,3), col=c("black","black","black"), 
       legend=c("3th grade","5th grade","8th grade") )

plot(density(posts_APS$Nu_free.3.), type="l",
     main="Intercepts \n Mathematics",
     xlab = "Unstandardized estimate")
lines(density(posts_APS$Nu_free.6.), col="black", lty=2)
lines(density(posts_APS$Nu_free.9.), col="black", lty=3)
par(mfrow=c(1,1))
dev.off()



#######
### PARTIAL STRONG INVARIANCE
#######

strong_Pmod <- '
#### factor loadings
ft3 =~ l1a*s_g3 + l2*r_g3 + l3*m_g3
ft5 =~ l1b*s_g5 + l2*r_g5 + l3*m_g5
ft8 =~ l1b*s_g8 + l2*r_g8 + l3*m_g8

#### residual covariances
s_g3 ~~ s_g5 + s_g8
s_g5 ~~ s_g8
r_g3 ~~ r_g5 + r_g8
r_g5 ~~ r_g8
m_g3 ~~ m_g5 + m_g8
m_g5 ~~ m_g8

#### Factor means
ft3 ~0*1
ft5 ~NA*1
ft8 ~NA*1

#### factor variances
ft3 ~~ 1*ft3
ft5 ~~ NA*ft5
ft8 ~~ NA*ft8

#### item intercepts
s_g3 ~i1a*1
r_g3 ~i2*1 
m_g3 ~i3*1
s_g5 ~i1b*1
r_g5 ~i2*1
m_g5 ~i3*1
s_g8 ~i1c*1
r_g8 ~i2*1
m_g8 ~i3*1
'

fit_Pstrong <- bcfa(strong_Pmod, 
                     std.lv=T,
                     data = dat,
                     n.chains = 3, 
                     burnin = 3000, 
                     sample = 1000,
                     target="stan",
                    dp=dpriors(lambda="normal(15, 10)"),
                     bcontrol = list(cores=3))

summary(fit_Pstrong, 
        standardize=T, 
        rsquare=T)
parameterestimates(fit_Pstrong)

## posterior draws

## compute differences across time
posts <- as.matrix(blavInspect(fit_Pstrong, "mcmc"))
dim(posts)
round(colMeans(posts),3)
round(apply(posts, 2, sd),3)
t(round(apply(posts, 2, FUN=function(x)quantile(x, probs=c(.025, .975))),3))

stp <- standardizedposterior(fit_Pstrong)
round(colMeans(stp),3)
round(apply(stp, 2, sd),3)
t(round(apply(stp, 2, FUN=function(x)quantile(x, probs=c(.025, .975))),3))

blavInspect(fit_Pstrong, "r2")
### fitmeasures output 
fm_Pstrong <- fitMeasures(fit_Pstrong)
fm_Pstrong

### approximate fit indices
apx_Pstrong <- blavFitIndices(fit_Pstrong, baseline.model = fit0)
apx_Pstrong
summary(apx_Pstrong,"mean")

### comparison: PARTIAL WEAK VS PARTIAL STRONG
comp_PWPS <- blavCompare(fit_Pweak, fit_Pstrong)
comp_PWPS


### comparison: STRONG VS PARTIAL STRONG
comp_SPS <- blavCompare(fit_strong, fit_Pstrong)
comp_SPS



#### Plot Posteriors
posts_PS <- data.frame(as.matrix(blavInspect(fit_Pstrong,"mcmc")))
head(posts_PS)

tiff("Plot3.tiff", width = 9.5, height = 5.5, units = 'in', 
     res = 300)
par(mfrow=c(1,2))
plot(density(posts_PS$Alpha_free.1.), type="l", col="black",
     main="Factor Means", xlim=c(0,2), lty=2,
     xlab = "Unstandardized estimate")
lines(density(posts_PS$Alpha_free.2.), col="black", lty=3)
abline(v=0, col="black")
legend("topright", lty=c(1,2,3), col=c("black","black","black"), 
       legend=c("3th grade","5th grade","8th grade") )

plot(density(posts_PS$Psi_var.1.), type="l", col="black", lty=2,
     main="Factor Variances",
     xlab = "Unstandardized estimate")
lines(density(posts_PS$Psi_var.2.), col="black", lty=3)
abline(v=1, col="black")
par(mfrow=c(1,1))
dev.off()


###########
###########
##### SECOND ORDER BASIS GROWTH MODEL
###########
###########

bgrowth_mod <- '
#### factor loadings
ft3 =~ 13.401*s_g3 + l2*r_g3 + l3*m_g3
ft5 =~ l1b*s_g5 + l2*r_g5 + l3*m_g5
ft8 =~ l1b*s_g8 + l2*r_g8 + l3*m_g8

#### residual covariances
s_g3 ~~ s_g5 + s_g8
s_g5 ~~ s_g8
r_g3 ~~ r_g5 + r_g8
r_g5 ~~ r_g8
m_g3 ~~ m_g5 + m_g8
m_g5 ~~ m_g8

#### item intercepts
s_g3 ~i1a*1
r_g3 ~i2*1 
m_g3 ~i3*1
s_g5 ~i1b*1
r_g5 ~i2*1
m_g5 ~i3*1
s_g8 ~i1c*1
r_g8 ~i2*1
m_g8 ~i3*1

##### basis/unstructure growth model
#### factor variances
ft3 ~~ NA*ft3
ft5 ~~ NA*ft5
ft8 ~~ NA*ft8
#### Factor means
ft3 ~0*1
ft5 ~0*1
ft8 ~0*1

Int =~ 1*ft3 + 1*ft5 + 1*ft8
Slp =~ 0*ft3 + ft5 + 1*ft8

Int ~~ Slp

Int ~~ NA*Int
Slp ~~ NA*Slp

Int ~0*1
Slp ~NA*1
'

fit_bgrowth <- bcfa(bgrowth_mod, 
                    std.lv=T,
                    orthogonal=T,
                    data = dat,
                    n.chains = 3, 
                    burnin = 6500, 
                    sample = 1000,
                    target="stan",
                    dp=dpriors(lambda="normal(15, 10)"),
                    bcontrol = list(cores=3, 
                                    control=list(max_treedepth=15,adapt_delta = 0.99) ),
                    inits="simple")

summary(fit_bgrowth, 
        standardize=T, 
        rsquare=T,
        neff=T)

summary(fit_bgrowth, 
        standardize=T, 
        rsquare=T,
        priors=F)

summary(fit_bgrowth)

stand_bgrowth <- standardizedposterior(fit_bgrowth)
head(stand_bgrowth)
brms::posterior_summary(stand_bgrowth[,"Int~~Slp"])

posts_bgrowth <- data.frame(as.matrix(blavInspect(fit_bgrowth, "mcmc")))
head(posts_bgrowth)
colMeans(posts_bgrowth)
partable(fit_bgrowth)

brms::posterior_summary((posts_bgrowth$bet_sign.1. * posts_bgrowth$Alpha_free.1.)/2)
brms::posterior_summary(( (1-posts_bgrowth$bet_sign.1.) * posts_bgrowth$Alpha_free.1.)/3)

brms::posterior_summary(posts_bgrowth$Psi_var.4. + posts_bgrowth$Psi_var.1.)

tiff("Plot3.tiff", width = 9.5, height = 5.5, units = 'in', 
     res = 300)
plot(density(posts_bgrowth$Psi_var.1.), col="black", lty=1,
     ylim=c(0,45),
     ylab="Density",
     xlab="Residual variance",
     main="Stationarity of the residual variances")
lines(density(posts_bgrowth$Psi_var.2.), col="black", lty=2)
lines(density(posts_bgrowth$Psi_var.3.), col="black", lty=3)
legend("topright", lty=c(1,2,3), col=c("black","black","black"), 
       legend=c("3th grade","5th grade","8th grade") )
dev.off()

brms::posterior_summary(posts_bgrowth$Psi_var.1. - posts_bgrowth$Psi_var.2.)
brms::posterior_summary(posts_bgrowth$Psi_var.1. - posts_bgrowth$Psi_var.3.)
brms::posterior_summary(posts_bgrowth$Psi_var.2. - posts_bgrowth$Psi_var.3.)

### fitmeasures output 
fm_bgrowth <- fitMeasures(fit_bgrowth)
fm_bgrowth

### approximate fit indices
apx_bgrowth <- blavFitIndices(fit_bgrowth, baseline.model = fit0)
apx_bgrowth
summary(apx_bgrowth,"mean")



### comparison: Basis growth VS PARTIAL STRONG
comp_BGPS <- blavCompare(fit_bgrowth, fit_Pstrong)
comp_BGPS


